@@ -220,5 +220,13 @@ class UdpSession(object):
                 datas = [','.join([str(x) for x in stats])]
                 cls.send_packet(PacketTypeEnum.ACTIVE_STATS, None, datas)
                 return
+            elif param_id == ParamDef.GET_DBCONN_POOL:
+                
+                stats = TraceContextManager.getDBConnPool()
+                pid = os.getpid()
+                strdbpool = '{}|{{}}|{{}}|{{}}'.format(pid)
+                datas = [','.join([strdbpool.format( k,act,inact) for k,(act,inact) in stats.items()])]
+                cls.send_packet(PacketTypeEnum.DBCONN_POOL, None, datas)
+                return
 
             cls.send_packet(PacketTypeEnum.TX_PARAM, None, datas)
